Welcome to hgan's documentation!
====================================

Welcome to hgan's documentation. This is a work in progress.

Quick start
-----------

hgan can be installed with ``pip``.
We recommend installing ``hgan`` in a separate anaconda environment.

   $ pip install hgan

The entry point for all hgan commands is the ``hgan`` executable::

   (hgan) $ hgan

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   pages/intro


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
